package springbootdemo;

import java.util.*;
import java.util.Map.Entry;
import org.springframework.core.env.*;

public class SpringEnvironmentPrintDevUtil
{
   /**
    * Anzeige von Spring-Environment-Properties (nur waehrend Entwicklung sinnvoll).
    * @param env ConfigurableEnvironment, z.B. mit: ConfigurableApplicationContext.getEnvironment()
    *                                          oder ConfigFileApplicationListener.postProcessEnvironment()
    *                                          oder ApplicationEnvironmentPreparedEvent.getEnvironment()
    * @param onlyPropSrcName Falls null: Anzeige aller Properties; sonst: nur Props aus PropertySource mit diesem Namen
    */
   public static void printSpringEnvironment( ConfigurableEnvironment env, String onlyPropSrcName )
   {
      for( Iterator<PropertySource<?>> itr = env.getPropertySources().iterator(); itr.hasNext(); ) {
         PropertySource<?> ps = itr.next();
         if( onlyPropSrcName != null && ps.getName() != null && !ps.getName().contains( onlyPropSrcName ) ) {
            continue;
         }
         System.out.println( "-----------------------------------------" );
         System.out.println( ps.getName() + " (" + ps.getClass() + ")" );
         if( ps instanceof EnumerablePropertySource ) {
            EnumerablePropertySource<?> eps = (EnumerablePropertySource<?>) ps;
            String[] pns = eps.getPropertyNames();
            Arrays.sort( pns );
            for( String pn : pns ) {
               System.out.println( "    " + pn + " = " + eps.getProperty( pn ) );
            }
         } else {
            System.out.println( "    PropertySource: " + ps.getSource().getClass() );
         }
      }
      System.out.println( "-----------------------------------------" );
   }

   /** Anzeige von Key/Value-Paaren einer Map. */
   public static void printMap( String title, Map<String,Object> mp, String prefix, String delimiter )
   {
      if( title != null ) { System.out.println( title ); }
      for( Entry<String,Object> entry : mp.entrySet() ) {
         System.out.println( prefix + entry.getKey() + delimiter + entry.getValue() );
      }
   }
}
