package springbootdemo;

import static org.hamcrest.Matchers.equalTo;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;
import org.junit.*;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.SpringApplicationConfiguration;
import org.springframework.http.MediaType;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.context.web.WebAppConfiguration;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.setup.MockMvcBuilders;
import org.springframework.web.context.WebApplicationContext;

@RunWith( SpringJUnit4ClassRunner.class )
@SpringApplicationConfiguration( classes = ControllerUndMain.class )
@WebAppConfiguration
public class DemoMvcRestServiceTest
{
   @Autowired
   private WebApplicationContext webContext;

   private MockMvc mockMvc;

   @Before
   public void setupMockMvc()
   {
      mockMvc = MockMvcBuilders.webAppContextSetup( webContext ).build();
   }

   @Test
   public void testPutDeleteGet() throws Exception
   {
      // "Anton" hinzufuegen:
      mockMvc.perform( put( "/mvc-rest/Anton" ).contentType( MediaType.APPLICATION_JSON ) )
             .andExpect( status().isOk() );
      // "Berta" hinzufuegen:
      mockMvc.perform( put( "/mvc-rest/Berta" ).contentType( MediaType.APPLICATION_JSON ) )
             .andExpect( status().isOk() );
      // "Anton" und "Berta" auslesen:
      mockMvc.perform( get( "/mvc-rest" ).accept( MediaType.APPLICATION_JSON ) )
             .andExpect( status().isOk() )
             .andExpect( content().contentType( MediaType.APPLICATION_JSON + ";charset=UTF-8" ) )
             .andExpect( content().string( equalTo( "[\"Anton\",\"Berta\"]" ) ) );
      // "Berta" loeschen:
      mockMvc.perform( delete( "/mvc-rest/1" ) )
             .andExpect( status().isOk() );
      // Nach Loeschung ist nur noch "Anton" vorhanden:
      mockMvc.perform( get( "/mvc-rest" ).accept( MediaType.APPLICATION_JSON ) )
             .andExpect( status().isOk() )
             .andExpect( content().string( equalTo( "[\"Anton\"]" ) ) );
   }
}
